import re
import MeCab
import os

checkNai = ["ない", "助動詞", "*", "*","*", "特殊・ナイ", "基本形", "ない"]
checkKei = ["形容動詞", "動詞"]

AverbSpecial = ["ぬ", "まい"]

godanGyoui = ["カ行イ音便", "ガ行"]
godanGyoultu = ["カ行促音便", "タ行", "ラ行", "ワ行促音便"]
godanGyousi = ["サ行"]
godanGyoun = ["ナ行", "バ行", "マ行"]
waReigai = ["問", "乞", "請"]
noHenkan = ["ほかなら", "他なら", "はず", "筈", "なくては", "無くては", "しか", "ざるを", "かも", "何も", "なにも"]

def DN(inputText, det) :
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")	
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger.parse('')

	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	if det :
		print(tagger.parse(inputText))

	# ！と。を前の文に含んで分割
	inputLines = []
	outputLines = []
	inputLines = re.split("(?<=。|！)", inputText)
	noHenkanFlag = 0
		
	# 分割したときに出る空白文字列を除去 
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)

	for i in range(0, lineCount, 1) :
		parts = []
		outputText = "tekitoudayo"
		meCount = 0
		changeFlag = 0
		impressFlag = 0
		hukusiFlag = 0

		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		while node:
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			if tmp1 == "感動詞" :
				impressFlag = 1
			elif impressFlag == 1 and "助" not in tmp1 :
				impressFlag = 0
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmp1 == "副詞" :
				hukusiFlag = 1

			if tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			# 文末が「ない」のとき、なにもしない
			if [tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7] == checkNai :
				changeFlag = 1

			meCount += 1
			if meCount == length:
				break

			# ノードを進める
			node = node.next

		if hukusiFlag == 1 :
			outputLines.append(inputLines[i])
			continue

		# 文末に記号が無いとき、一時的につけて最後に除去する
		if tmp1 != "記号" :
			parts.append(["!。！", "記号", "**", "**", "**", "**", "**", "**"])

		partsLength = len(parts)
	
		for j in range(0, partsLength, 1) :
			for k in range(0, len(noHenkan), 1) :
				if noHenkan[k] in inputLines[i] :
					outputLines.append(inputLines[i])
					noHenkanFlag = 1

			if noHenkanFlag == 1 :
				noHenkanFlag = 0
				break

			if parts[j][2]  == "格助詞" and parts[j + 1][2] == "係助詞" and (parts[j + 2][0] == "ない" or parts[j + 2][0] == "なかっ" or parts[j + 2][0] == "ません") :
				pass

			if partsLength - 1 >= j + 2 and parts[j + 1][0] == "ませ" and parts[j + 1][1] == "助動詞" and "命令" not in parts[j + 1][6] and (parts[j + 3][0] == "。" or parts[j + 3][2] == "終助詞" or parts[j + 3][1] == "助動詞") :
				if j - 1 > 0 and parts[j - 1][2] == "副助詞" :
					pass

				elif partsLength - 1 >= j + 3 and parts[j + 3][0] == "でし" :
					parts[j + 1][0] = "ました"
				
				else :
					parts[j + 1][0] = parts[j + 1][7]

				if parts[j + 1][0] == "ます" :
					k = j + 2
					while parts[k][1] == "助動詞" :
						parts[k][0] = ""
						k += 1

			elif partsLength - 1 >= j + 1 and parts[j + 1][0] in AverbSpecial and parts[j + 1][1] == "助動詞" :
				parts[j][0] = parts[j][7]
				parts[j + 1][0] = ""

			elif j - 1 >= 0 and "ナイ" in parts[j - 1][2] and parts[j][1] != "助動詞" :
				pass

			elif j - 1 >= 0 and parts[j - 1][2] != "副助詞" and partsLength - 1 >= j + 1 and (parts[j + 1][0] == "ない" or parts[j + 1][0] == "無い") and (parts[j + 1][1] == "助動詞" and ("非" not in parts[j][2] or "非" in parts[j][2] and parts[j][6] == "未然形" or (partsLength - 1 >= j + 3 and parts[j + 2][1] == "名詞" and "非" in parts[j + 2][2] and parts[j + 3][1] == "助動詞")) or (parts[j][1] == "助詞" or parts[j][1] == "動詞") and (parts[j + 1][1] == "形容詞" or parts[j][2] == "副助詞")) and (parts[j + 2][1] == "助動詞" and "デス" in parts[j + 2][5] or parts[j + 2][1] == "記号" or parts[j + 2][2] == "終助詞" or "ダ" in parts[j + 2][5] and parts[j + 2][6] == "未然形" or parts[j + 2][1] == "名詞" and "非" in parts[j + 2][2] and parts[j + 3][1] == "助動詞") :
				if j - 1 > 0 and parts[j - 1][1] == "助動詞" and parts[j][1] == "助詞" and parts[j][2] == "係助詞" :
					outputLines.remove(parts[j - 1][0])
					parts[j][0] = parts[j - 1][7]
					parts[j + 1][0] = ''

				elif j - 1 > 0 and parts[j - 1][1] == "助詞" and parts[j - 1][2] != "接続助詞" and parts[j - 1][2] == "格助詞" and parts[j][2] == "係助詞" :
					parts[j][0] = ""
					parts[j + 1][0] = "ある"

				elif j - 1 > 0 and parts[j - 1][2] == "係助詞" and parts[j][1] == "形容詞" :
					parts[j][0] = parts[j][7]
					parts[j + 1][0] = ''

				# 「〜ならない」、「〜いけない」とかも変換しちゃう
				elif parts[j][6] == "未然形" and parts[j + 1][1] == "助動詞" :
					parts[j][0] = parts[j][7]
					parts[j + 1][0] = ''
				
				elif parts[j][2] == "副助詞" :
					parts[j][0] = ''
					parts[j + 1][0] = ''

				elif parts[j][6] != "未然形" and j - 1 > 0 and (parts[j - 1][2] == "係助詞" or parts[j - 1][2] == "副助詞") :
					pass

				elif "非" in parts[j - 1][2] and parts[j][1] == "助詞" :
					parts[j + 1][0] = "ある"

				elif "非" not in parts[j - 1][2] and parts[j][2] == "格助詞" :
					parts[j + 1][0] = "ある"

				elif j - 1 > 0 and parts[j - 1][0] == "ば" and parts[j][1] == "動詞" :
					pass

				elif parts[j][1] == "動詞" and "連用" in parts[j + 1][6] :
					pass

				elif parts[j][2] == "係助詞" and parts[j + 1][1] == "形容詞" :
					pass

				elif parts[j][1] == "動詞" and parts[j + 1][1] == "形容詞" :
					parts[j + 1][0] = "る"

				elif j - 1 > 0 and (j - 2 > 0 and parts[j - 2][2] == "格助詞" and parts[j - 1][2] == "係助詞" or parts[j - 1][2] != "係助詞") and parts[j - 1][1] != "副詞" and parts[j][1] == "動詞" :
					parts[j][0] = parts[j][7]
					parts[j + 1][0] = ''

				elif parts[j][1] == "助動詞" and "連用" in parts[j][6] :
					parts[j][0] = parts[j][7]
					parts[j + 1][0] = ''

				elif parts[j][1] == "形容詞" :
					parts[j][0] = parts[j][7]
					parts[j + 1][0] = ''

				elif parts[j][1] == "助詞" :
					parts[j + 1][0] = "ある"

				#「ならない」を変換してしまう
				# elif parts[j][1] == "動詞" :
				#	print(inputLines[i])

			elif j - 1 >= 0 and parts[j - 1][2] != "副助詞" and partsLength - 1 >= j + 1 and (parts[j + 1][0] == "なかっ" or parts[j + 1][0] == "無かっ") and (parts[j + 1][1] == "助動詞" and ("非" not in parts[j][2] or "非" in parts[j][2] and parts[j][6] == "未然形") or (parts[j][1] == "助詞" or parts[j][1] == "動詞") and parts[j + 1][1] == "形容詞") and parts[j + 2][0] == "た" and (parts[j + 3][1] == "記号" or parts[j + 3][2] == "終助詞" or "ダ" in parts[j + 3][5] and parts[j + 3][6] == "未然形") :
				if parts[j][0] in noHenkan :
					pass

				elif j - 1 > 0 and parts[j - 1][1] == "助動詞" and parts[j][1] == "助詞" and parts[j][2] == "係助詞" :
					outputLines.remove(parts[j - 1][0])
					parts[j][0] = parts[j - 1][7] + "っ"
					parts[j + 1][0] = ''

				elif j - 1 > 0 and parts[j - 1][1] == "助詞" and parts[j - 1][2] != "係助詞" and parts[j][1] == "形容詞" :
					parts[j][0] = parts[j][7][:-1]
					parts[j + 1][0] = "かっ"

				elif j - 1 > 0 and parts[j - 1][2] == "格助詞" and parts[j][2] == "係助詞" and parts[j + 1][1] == "形容詞" :
					parts[j][0] = ""
					parts[j + 1][0] = "あっ"

				elif parts[j][1] == "助詞" and parts[j][2] == "係助詞" and parts[j + 1][1] == "形容詞" :
					parts[j + 1][0] = "あっ"

				elif parts[j][1] == "形容詞" :
					parts[j][0] = parts[j][0][:-1]
					parts[j + 1][0] = parts[j + 1][0][1:]

				elif parts[j][2] == "副助詞" :
					parts[j][0] = ''
					parts[j + 1][0] = "だっ"

				elif j - 1 > 0 and parts[j - 1][0] == "ば" and parts[j][1] == "動詞" :
					pass

				elif parts[j][2] == "係助詞" and parts[j + 1][1] == "形容詞" :
					parts[j + 1][0] = "あっ"

				elif parts[j][1] == "動詞" and parts[j + 1][1] == "形容詞" :
					parts[j + 1][0] = ''

				elif parts[j][1] == "助動詞" :
					if "タイ" in parts[j][5] :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = parts[j + 1][0][1:]

					elif "イ" in parts[j][5] :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = parts[j + 1][0][1:]
					
					else :
						parts[j][0] = parts[j][7]
						parts[j + 1][0] = "っ"

				elif parts[j][1] == "動詞" :
					if "・" not in parts[j][5] :
						parts[j + 1][0] = ''

					elif re.search("(?<=・).+", parts[j][5]).group() in godanGyoultu and parts[j][0][:-1] in waReigai :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "う"

					elif re.search("(?<=・).+", parts[j][5]).group() in godanGyoui :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "い"
	
					elif re.search("(?<=・).+", parts[j][5]).group() in godanGyoultu :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "っ"

					elif re.search("(?<=・).+", parts[j][5]).group() in godanGyousi :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "し"

					elif re.search("(?<=・).+", parts[j][5]).group() in godanGyoun :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "ん"
						parts[j + 2][0] = "だ"

					elif parts[j][2] == "接尾" :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = parts[j + 1][0][2:]

					elif "促音" in parts[j][5] :
						parts[j][0] = parts[j][0][:-1]
						parts[j + 1][0] = "っ"

					else :
						parts[j + 1][0] = ''

				elif parts[j][1] == "助詞" :
					parts[j + 1][0] = "あっ"

			else :
				pass

			outputLines.append(parts[j][0])

	return ''.join(outputLines).replace("!。！", '') + '\n'



import re
import MeCab
import os

gimonsiTati = ["ナニ", "ドレ", "ドチラ", "ドッチ", "ドナタ", "ドコ", "ダレ", "イツ", "イクラ", "イクツ", "ドノ", "ドウ", "ドウシテ", "ナゼ", "ドンナ", "ナン", "イカニ", "イズコ", "イカナル"]

def QN(inputText, det) :
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")	
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger.parse('')

	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	if det :
		print(tagger.parse(inputText))

	# ！と。を前の文に含んで分割
	inputLines = []
	outputLines = []
	inputLines = re.split("(?<=。|！)", inputText)
	
	# 分割したときに出る空白文字列を除去 
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)

	for i in range(0, lineCount, 1) :
		parts = []
		outputText = "tekitoudayo"
		meCount = 0
		changeFlag = 0
		impressFlag = 0
		gimonsiFlag = 0

		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		while node:
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			if tmp1 == "感動詞" :
				impressFlag = 1
			elif impressFlag == 1 and "助" not in tmp1 :
				impressFlag = 0
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmp7 in gimonsiTati :
				gimonsiFlag = 1

			if tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			meCount += 1
			if meCount == length:
				break

			# ノードを進める
			node = node.next

		# 文末に記号が無いとき、一時的につけて最後に除去する
		if tmp1 != "記号" :
			parts.append(["!。！", "記号", "**", "**", "**", "**", "**", "**"])

		partsLength = len(parts)

		for j in range(0, partsLength, 1) :
			if parts[j][0] in gimonsiTati :
				pass

			if partsLength - 1 >= j + 1 and parts[j][0] == "か" and parts[j + 1][1] == "記号" and parts[j][1] == "助詞" and parts[j][2] == "副助詞／並立助詞／終助詞" :
				parts[j][0] = ''
				parts[j + 1][0] = "。"

			elif partsLength - 1 >= j + 3 and "ダ" in parts[j][5] and parts[j][6] == "体言接続" and parts[j + 2][0] == "か" and parts[j + 3][1] == "記号" and parts[j + 2][1] == "助詞" and parts[j + 2][2] == "副助詞／並立助詞／終助詞" :
				parts[j][0] = "だ"
				parts[j + 1][0] = ''
				parts[j + 2][0] = ''
				parts[j + 3][0] = "。"
			
			else :
				pass

			outputLines.append(parts[j][0])

	return ''.join(outputLines) + '\n'



import re
import MeCab
import os

Dfeatures  = ["ない", "無い", "なかっ", "無かっ", "ません"]

def SPJ(inputText):
	tagger = MeCab.Tagger()
	
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")
	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	# ！と。を前の文に含んで分割
	inputLines = []
	inputLines = re.split("(?<=。|！)", inputText)
	
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)

	for i in range(0, lineCount, 1) :
		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		parts = []
		tmpSurface = 0
		tmp1 = 0
		tmp2 = 0
		tmp3 = 0
		tmp4 = 0
		tmp5 = 0
		tmp6 = 0
		meCount = 0
		changeFlag = 0

		while node:
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			meCount += 1
			if meCount == length:
				break

			# ノードを進める
			node = node.next

		if tmp1 != "記号" :
			parts.append(["!。！", "記号", "**", "**", "**", "**", "**", "**"])

		partsLength = len(parts)

		verbCount = 0

		for j in range(partsLength - 1, -1, -1) :
			if parts[j][1] == "動詞" :
				verbCount += 1
			if parts[j][0] == "？" or (parts[j][0] == "。" or parts[j][0] == "！") and parts[j - 1][0] == "か":
				sp = "q"
				break

			elif parts[j][0] in Dfeatures and (parts[j][1] == "助動詞" or parts[j][1] == "形容詞") :
				sp = "d"
				break

			elif "命令" in parts[j][6] and verbCount == 1:
				sp = "o"
				break

			else :
				sp = "n"

	return sp



import re
import MeCab
import os

checkNai = ["ない", "助動詞", "*", "*","*", "特殊・ナイ", "基本形", "ない"]
AverbKei = ["たい", "らしい", "たかっ", "らしかっ"]
AverbSpecial = ["ます", "です", "だ", "た", "まし", "でし", "だっ"]
AverbSpecialHen = ["マス", "デス", "ダ", "タ"]
		

def ND(inputText, det):
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger.parse('')
	
	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	if det :
		print(tagger.parse(inputText))

	# ！と。を前の文に含んで分割
	inputLines = []
	outputLines = []
	inputLines = re.split("(?<=。|！|、)", inputText)
	
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)
	mikkeFlag = 0

	for i in range(0, lineCount, 1) :
		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		parts = []
		outputText = "tekitoudayo"
		impressFlag = 0
		tmpSurface = 0
		tmp1 = 0
		tmp2 = 0
		tmp3 = 0
		tmp4 = 0
		tmp5 = 0
		tmp6 = 0
		meCount = 0
		changeFlag = 0

		while node:
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			if tmp1 == "感動詞" :
				impressFlag = 1
			elif impressFlag == 1 and "助" not in tmp1 :
				impressFlag = 0
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			if [tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7] == checkNai :
				changeFlag = 1

			meCount += 1
			if meCount == length:
				break

			# ノードを進める
			node = node.next

		if tmp1 != "記号" :
			parts.append(["!。！", "記号", "**", "**", "**", "**", "**", "**"])

		partsLength = len(parts)

		for j in range(0, partsLength, 1) :
			if parts[partsLength - 1][0] == "、" :
				outputLines.append(inputLines[i])
				break

			elif j - 1 >= 0 and parts[j - 1][1] == "感動詞" :
				outputText = parts[j][0]

				changeFlag = 1
				k = j
				while partsLength - 1 >= k :
					if parts[k][1] == "動詞" or parts[k][1] == "形容詞" or parts[k][1] == "形容動詞" :
						changeFlag = 0
					k += 1

			elif (parts[j][0] == "ない" or parts[j][0] == "無い") and (parts[j][1] == "形容詞" or parts[j][1] == "助動詞") and changeFlag == 0 :
				outputText = parts[j][0]

				changeFlag = 1

			elif (parts[j][0] == "なかっ" or parts[j][0] == "無かっ") and parts[j + 1][0] == "た" and changeFlag == 0 :
				outputText = parts[j][0]

				changeFlag = 1

			elif partsLength - 1 >= j + 1 and "接続" in parts[j + 1][2] and (parts[j][0] == "。" or parts[j][0] == "！") :
				outputText = parts[j][0]

			elif parts[j][0] in AverbKei and changeFlag == 0 :
				if parts[j][0] == "たい" :
					outputText = "たくない"

				elif parts[j][0] == "らしい" :
					outputText = "らしくない"

				elif parts[j][0] == "たかっ" :
					outputText = "たくなかっ"

				elif parts[j][0] == "らしかっ" :
					outputText = "らしくなかっ"

				changeFlag = 1

			elif parts[j][0] in AverbSpecial and parts[j - 1][1] != "形容詞" and parts[j - 1][0] == outputText and parts[j + 1][1] != "形容詞" and parts[j + 1][1] != "動詞" and "形容動詞" not in parts[j + 1][2] and not (parts[j - 1][1] == "動詞" and parts[j + 1][1] == "名詞" and "助動詞" not in parts[j + 1][3]) and "副" not in parts[j + 1][2] and parts[j + 1][0] != "、" and changeFlag == 0 :
				if parts[j][0] == "ます" :
					outputText = "ません"

				elif parts[j][0] == "です" :
					outputText = "じゃないです"

				elif parts[j][0] == "た" :
					outputText = "なかった"

				elif parts[j][0] == "だ" :
				 	outputText = "でない"

				elif parts[j][0] == "まし" :
					outputText = "ませんでし"

				elif parts[j][0] == "でし" :
					outputText = "じゃなかっ"

				elif parts[j][0] == "だっ" :
				 	outputText = "でなかっ"

				changeFlag = 1

			elif "・" in parts[j][5] and re.search("(?<=・).+", parts[j][5]).group() in AverbSpecialHen and parts[j][6] != "連用形" and parts[j][6] != "仮定形" and parts[j - 1][1] != "形容詞" and parts[j - 1][0] == outputText and parts[j + 1][1] != "形容詞" and parts[j + 1][1] != "動詞" and "形容動詞" not in parts[j + 1][2] and not (parts[j - 1][1] == "動詞" and parts[j + 1][1] == "名詞") and ("副" not in parts[j + 1][2] or (parts[j - 1][1] == "名詞" and "非" not  in parts[j - 1][2])) and changeFlag == 0 :

				if "マス" in parts[j][5] :
					outputText = "ません"

				elif "デス" in parts[j][5] :
					outputText = "じゃないです"

				elif "タ" in parts[j][5] :
					outputText = "なかった"

				elif "ダ" in parts[j][5] :
				 	outputText = "でない"

				changeFlag = 1

				k = j + 1
				while partsLength - 1 >= k :
					if parts[k][1] == "名詞" or parts[k][1] == "動詞" or parts[k][1] == "形容詞" :
						break
					k += 1

				if partsLength == k :
					k = j + 1
					while partsLength - 1 >= k and (parts[k][1] == "助動詞" or parts[k][1] == "副詞") :
						parts[k] = ["", "", "", "", "", "", "", ""]
						k += 1

			elif parts[j][1] == "連体詞" and (partsLength - 1 == j or partsLength - 1 >= j + 1 and parts[j + 1][1] == "記号") and changeFlag == 0 :
				if parts[j + 1][0] == "。" or parts[j + 1][0] == "！" :
					outputText = parts[j][0] + "でない"

				else :
					outputText = parts[j][0]

			elif parts[j][1] == "形容詞" and partsLength - 1 >= j + 1 and parts[j + 1][1] == "名詞" :
				outputText = parts[j][0]

			elif parts[j][1] == "形容詞" and changeFlag == 0 :
				changeFlag = 1
				
				if "未然" in parts[j][6] :
					outputText = parts[j][7][:-1] + parts[j][0].replace(parts[j][7][:-1], "くな", 1) 
			
				elif "連用" in parts[j][6] and "並立" not in parts[j + 1][2]:
					if "タ" in parts[j][6] :
						outputText = parts[j][7][:-1] + parts[j][0].replace(parts[j][7][:-1], "くな", 1) 

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" :
					if parts[j][0] == "いい" :
						outputText = "よくない"

					else :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "いなく", 1)[::-1]
				
				elif parts[j][6] == "仮定形" :
					outputText = parts[j][7][:-1] + parts[j][0].replace(parts[j][7][:-1], "くな", 1) 

				else :
					outputText = parts[j][0]
					changeFlag = 0

			elif "形容動詞" in parts[j - 1][2] and parts[j][6] == "基本形" and changeFlag == 0 :
				outputText = parts[j][0] + "でない"

				changeFlag = 1

			elif "助動詞" in parts[j - 1][3] and "非" not in parts[j - 1][2] and changeFlag == 0 :
				changeFlag = 1

				if "形容詞" in parts[j][5] :
					outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "いなで", 1)[::-1]

				elif "副詞" in parts[j][2] :
					outputText = parts[j][0]
					changeFlag = 0

				else :
					outputText = "でない"

			elif partsLength - 1 >= j + 1 and parts[j + 1][0] == "まい" and changeFlag == 0 :
				outputText = parts[j][0]

			elif parts[j][0] == "ある" and parts[j][1] == "動詞" and changeFlag == 0 :
				outputText = "ない"
				
				changeFlag = 1

			elif parts[j][0] == "あっ" and parts[j][1] == "動詞" and "ワ" in parts[j][5] and changeFlag == 0 :
				outputText = "なかっ"
				
				changeFlag = 1

			elif parts[j][0] == "ある" and parts[j][1] == "助動詞" and changeFlag == 0 :
				outputText = "ない"
				
				changeFlag = 1

			elif parts[j][1] == "副詞" and (partsLength - 1 == j or partsLength - 1 >= j + 1 and parts[j + 1][1] == "記号") and changeFlag == 0 :
				if parts[j + 1][0] == "。" or parts[j + 1][0] == "！" :
					outputText = parts[j][0] + "でない"

				else :
					outputText = parts[j][0]

			elif parts[j][1] == "副詞" and "助詞" not in parts[j][2] and partsLength - 1 >= j + 1 and parts[j + 1][1] != "形容詞" and parts[j + 1][1] != "副詞" and parts[j + 1][1] != "名詞" and parts[j + 1][1] != "感動詞" and changeFlag == 0 :
				outputText = parts[j][0] + "でない"
				
				changeFlag = 1

				k = j + 1
				while partsLength - 1 >= k :
					if parts[k][1] == "名詞" or parts[k][1] == "動詞" or parts[k][1] == "形容詞" :
						break
					k += 1

				if partsLength == k :
					k = j + 1
					while partsLength - 1 >= k and (parts[k][1] == "助動詞" or parts[k][1] == "副詞") :
						parts[k] = ["", "", "", "", "", "", "", ""]
						k += 1

				if partsLength - 1 >= j + 1 and parts[j + 1][2] == "連体化" :
					parts[j + 1] = ["", "", "", "", "", "", "", ""]

			elif parts[j][1] == "名詞" and (partsLength - 1 == j or partsLength - 1 >= j + 1 and parts[j + 1][1] == "記号" and "非" not in parts[j][2]) and changeFlag == 0 :
				if parts[j][2] != "接尾" and parts[j][3] != "人名" and (parts[j + 1][0] == "。" or parts[j + 1][0] == "！") :
					outputText = parts[j][0] + "でない"
				else :
					outputText = parts[j][0]

			elif parts[j][1] == "名詞" and "助動詞" in parts[j + 1][1] and partsLength - 1 >= j + 2 and parts[j + 2][1] == "名詞" and changeFlag == 0 :
				outputText = parts[j][0]

			elif parts[j][1] == "名詞" and "助動詞" in parts[j + 1][1] and changeFlag == 0 :
				if parts[j + 1][0] in AverbSpecial :
					outputText = parts[j][0]
					
					changeFlag = 0

				else :
					outputText = parts[j][0]

			elif parts[j][1] == "動詞" and partsLength - 1 >= j + 1 and parts[j + 1][1] == "名詞" and "非" not in parts[j + 1][2]:
				outputText = parts[j][0]

			elif "命令" in parts[j][6] and changeFlag == 0 :
				if  j - 1 >= 0 and "係" in parts[j - 1][2] :
					outputText = parts[j][0]

				else :
					outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
					changeFlag = 1

			elif partsLength - 1 >= j + 2 and parts[j][1] == "動詞" and "連用" in parts[j][6] and parts[j + 1][1] == "助動詞" and (parts[j + 2][1] == "名詞" and "助動詞" not in parts[j + 2][3]) and  changeFlag == 0 :
				outputText = parts[j][0]

			elif "五段" in parts[j][5] and changeFlag == 0 :
				changeFlag = 1

				if "未然" in parts[j][6] :
					if parts[j + 1][0] == "う" :
						kata = re.search("(?<=・).", parts[j][5])
						change = "".join(chr(ord(kata.group()) - 96))
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "よいでいな" + change, 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" not in parts[j][2] :
					if "命令" in parts[j + 1][6] :
						outputText = parts[j][0]
					
					elif partsLength - 1 >= j + 2 and "副" in parts[j + 2][2] and parts[j + 2][1] != "助詞" :
						outputText = parts[j][0]
						changeFlag = 0

					elif "助動詞" in parts[j + 1][3] :
						kata = re.search("(?<=・).", parts[j][5])
						change = "".join(chr(ord(kata.group()) - 96))
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "な" + change, 1)[::-1]

					elif parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" or parts[j + 1][0] == "だ" :
							kata = re.search("(?<=・).", parts[j][5])
							change = "".join(chr(ord(kata.group()) - 96))
							outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "っかな" + change, 1)[::-1]

							kata = re.search("(?<=・).", parts[j + 1][5])
							change = "".join(chr(ord(kata.group()) - 96))
							parts[j + 1][0] = parts[j + 1][0].replace(parts[j + 1][0][0], change)

						else :
							outputText = parts[j][0]
							changeFlag = 0

					elif "接続" in parts[j + 1][2] and partsLength - 1 >= j + 2 and (parts[j + 2][0] == "。"or parts[j + 2][0] == "！") :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						parts[j + 1] = ["", "", "", "", "", "", "", ""]
						changeFlag = 1

					elif "終助詞" in parts[j + 1][2] :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" in parts[j][2] and parts[j - 1][1] != "動詞" :
					if parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] not in AverbKei and parts[j + 1][0][0] == "た" or parts[j + 1][0][0] == "だ" :
							kata = re.search("(?<=・).", parts[j][5])
							change = "".join(chr(ord(kata.group()) - 96))
							outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "っかな" + change, 1)[::-1]
							
							kata = re.search("(?<=・).", parts[j + 1][5])
							change = "".join(chr(ord(kata.group()) - 96))
							parts[j + 1][0] = parts[j + 1][0].replace(parts[j + 1][0], change)
						
						else :
							outputText = parts[j][0]
							changeFlag = 0

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" or parts[j][6] == "連体形" :
					if partsLength - 1 >= j + 1 and ("接続" in parts[j + 1][2] or "接続" in parts[j + 1][6]) :
						outputText = parts[j][0]
						changeFlag = 0

					elif partsLength - 1 >= j + 1 and "副" in parts[j + 1][2] or "格" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif "非" not in parts[j][2] and partsLength - 1 >= j + 1 and "非" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					else :
						kata = re.search("(?<=・).", parts[j][5])
						change = "".join(chr(ord(kata.group()) - 96))
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "いな" + change, 1)[::-1]
			
				elif parts[j][6] == "仮定形" :
					kata = re.search("(?<=・).", parts[j][5])
					change = "".join(chr(ord(kata.group()) - 96))
					outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "れけな" + change, 1)[::-1]

				else :
					outputText = parts[j][0]
					changeFlag = 0
			
			elif "一段" in parts[j][5] and changeFlag == 0 :
				changeFlag = 1

				if "未然" in parts[j][6] :
					if parts[j][0][-1:] == "よ" and parts[j + 1][0] == "う" :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "よいでいな", 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" not in parts[j][2] :
					if "命令" in parts[j + 1][6] :
						outputText = parts[j][0]
					
					elif partsLength - 1 >= j + 2 and "副" in parts[j + 2][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" or parts[j + 1][0] == "だ" :
							outputText = parts[j][0] + "なかっ"

						elif parts[j + 1][0] == "ます" :
							outputText = parts[j][0]
							changeFlag = 0
						
						elif parts[j + 1][6] == "仮定形" :
							outputText = parts[j][0] + "なかっ"
						
						else :
							outputText = parts[j][0]
							changeFlag = 0

					elif "接続" in parts[j + 1][2] and partsLength - 1 >= j + 2 and (parts[j + 2][0] == "。"or parts[j + 2][0] == "！") :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						parts[j + 1] = ["", "", "", "", "", "", "", ""]
						changeFlag = 1

					elif "終助詞" in parts[j + 1][2] :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0
				
				elif "連用" in parts[j][6] and "非" in parts[j][2] and parts[j - 1][1] != "動詞" :
					if parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" or parts[j + 1][0] == "だ" :
							outputText = parts[j][0] + "なかっ"

						elif parts[j + 1][0] == "ます" :
							outputText = parts[j][0]
							changeFlag = 0
						
						else :
							outputText = parts[j][0]
							changeFlag = 0

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" or parts[j][6] == "連体形" :
					if partsLength - 1 >= j + 1 and ("接続" in parts[j + 1][2] or "接続" in parts[j + 1][6]) :
						outputText = parts[j][0]
						changeFlag = 0

					elif partsLength - 1 >= j + 1 and "副" in parts[j + 1][2] or "格" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif "非" not in parts[j][2] and partsLength - 1 >= j + 1 and "非" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					else :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "いな", 1)[::-1]
				
				elif parts[j][6] == "仮定形" :
					outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "れけな", 1)[::-1]

				else :
					outputText = parts[j][0]
					changeFlag = 0
			
			elif "カ変" in parts[j][5] and changeFlag == 0 :
				changeFlag = 1
				koFlag = 0

				if "未然" in parts[j][6] :
					if parts[j][0][-1:] == "よ" and parts[j + 1][0] == "う" :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "よいでいな", 1)[::-1]
						koFlag = 1

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] :
					if "命令" in parts[j + 1][6] :
						outputText = parts[j][0]
					
					elif partsLength - 1 >= j + 2 and "副" in parts[j + 2][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" or parts[j + 1][0] == "だ" :
							outputText = parts[j][0] + "なかっ"
							koFlag = 1

						elif parts[j + 1][0] == "ます" :
							outputText = parts[j][0]
							changeFlag = 0

						else :
							outputText = parts[j][0]
							changeFlag = 0

					elif "接続" in parts[j + 1][2] and partsLength - 1 >= j + 2 and (parts[j + 2][0] == "。"or parts[j + 2][0] == "！") :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						parts[j + 1] = ["", "", "", "", "", "", "", ""]
						changeFlag = 1

					elif "終助詞" in parts[j + 1][2] :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						koFlag = 1

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" or parts[j][6] == "連体形" :
					if partsLength - 1 >= j + 1 and ("接続" in parts[j + 1][2] or "接続" in parts[j + 1][6]) :
						outputText = parts[j][0]
						changeFlag = 0

					elif partsLength - 1 >= j + 1 and "副" in parts[j + 1][2] or "格" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif "非" not in parts[j][2] and partsLength - 1 >= j + 1 and "非" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					else :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "いな", 1)[::-1]
						koFlag = 1

				elif parts[j][6] == "仮定形" :
					outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "れけな", 1)[::-1]
					koFlag = 1

				else :
					outputText = parts[j][0]
					changeFlag = 0

				if "来" not in parts[j][0] and koFlag == 1 :
					outputText = outputText.replace(parts[j][0][0], "こ")
					koFlag = 0

			elif "サ変" in parts[j][5] and "スル" in parts[j][5] and parts[j][1] == "動詞" and changeFlag == 0 :
				changeFlag = 1

				if "未然" in parts[j][6] :
					if parts[j][0][-1:] == "よ" and parts[j + 1][0] == "う" :
						outputText = parts[j][0][::-1].replace(parts[j][0][-1:], "よいでいな", 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" not in parts[j][2] :
					if "命令" in parts[j + 1][6] :
						outputText = parts[j][0]
					
					elif partsLength - 1 >= j + 2 and "副" in parts[j + 2][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" :
							if partsLength - 1 >= j + 2 and (parts[j + 2][1] == "動詞" or "副" in parts[j + 2][2]) :
								outputText = parts[j][0]
								changeFlag = 0
							
							else :
								outputText = parts[j][0] + "なかっ"

						else :
							outputText = parts[j][0]
							changeFlag = 0

					elif "接続" in parts[j + 1][2] and partsLength - 1 >= j + 2 and (parts[j + 2][0] == "。"or parts[j + 2][0] == "！") :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						parts[j + 1] = ["", "", "", "", "", "", "", ""]
						changeFlag = 1

					elif "終助詞" in parts[j + 1][2] :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" in parts[j][2] and parts[j - 1][1] != "動詞" :
					if parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" :
							if partsLength - 1 >= j + 2 and (parts[j + 2][1] == "動詞" or "副" in parts[j + 2][2]) :
								outputText = parts[j][0]
								changeFlag = 0
							
							else :
								outputText = parts[j][0] + "なかっ"

						else :
							outputText = parts[j][0]
							changeFlag = 0
				
					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" or parts[j][6] == "連体形" :
					if partsLength - 1 >= j + 1 and ("接続" in parts[j + 1][2] or "接続" in parts[j + 1][6]) :
						outputText = parts[j][0]
						changeFlag = 0

					elif partsLength - 1 >= j + 1 and "副" in parts[j + 1][2] or "格" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0
	
					elif "非" not in parts[j][2] and partsLength - 1 >= j + 1 and "非" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					else :
						outputText = parts[j][0][::-1].replace("るす", "いなし", 1)[::-1]
				
				elif parts[j][6] == "仮定形" :
					outputText = parts[j][0][::-1].replace("れす", "れけなし", 1)[::-1]

				else :
					outputText = parts[j][0]
					changeFlag = 0
			
			elif "サ変" in parts[j][5] and "ズル" in parts[j][5] and "未然" not in parts[j][6] and parts[j][1] == "動詞" and changeFlag == 0 :
				changeFlag = 1

				if "連用" in parts[j][6] and "非" not in parts[j][2] :
					if "命令" in parts[j + 1][6] :
						outputText = parts[j][0]
					
					elif partsLength - 1 >= j + 2 and "副" in parts[j + 2][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" :
							outputText = parts[j][0] + "なかっ"
						
						elif parts[j + 1][0] == "ます" :
							outputText = parts[j][0]
							changeFlag = 0
				
						else :
							outputText = parts[j][0]
							changeFlag = 0

					elif "接続" in parts[j + 1][2] and partsLength - 1 >= j + 2 and (parts[j + 2][0] == "。"or parts[j + 2][0] == "！") :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]
						parts[j + 1] = ["", "", "", "", "", "", "", ""]
						changeFlag = 1

					elif "終助詞" in parts[j + 1][2] :
						outputText = parts[j][0][::-1].replace(parts[j][0][::-1], "な" + parts[j][7][::-1], 1)[::-1]

					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif "連用" in parts[j][6] and "非" in parts[j][2] and parts[j - 1][1] != "動詞" :
					if parts[j + 1][1] == "助動詞" :
						if parts[j + 1][0] == "た" :
							outputText = parts[j][0] + "なかっ"
						
						elif parts[j + 1][0] == "ます" :
							outputText = parts[j][0]
							changeFlag = 0
				
						else :
							outputText = parts[j][0]
							changeFlag = 0
				
					else :
						outputText = parts[j][0]
						changeFlag = 0

				elif parts[j][6] == "基本形" or parts[j][6] == "連体形" :
					if partsLength - 1 >= j + 1 and ("接続" in parts[j + 1][2] or "接続" in parts[j + 1][6]) :
						outputText = parts[j][0]
						changeFlag = 0

					elif partsLength - 1 >= j + 1 and "副" in parts[j + 1][2] or "格" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					elif "非" not in parts[j][2] and partsLength - 1 >= j + 1 and "非" in parts[j + 1][2] :
						outputText = parts[j][0]
						changeFlag = 0

					else :
						outputText = parts[j][0][::-1].replace("るず", "いなじ", 1)[::-1]
				
				elif parts[j][6] == "仮定形" :
					outputText = parts[j][0][::-1].replace("れず", "れけなじ", 1)[::-1]

				else :
					outputText = parts[j][0]
					changeFlag = 0
			
			else :
				outputText = parts[j][0]

			k = j + 1
			checkKei = ["形容動詞", "動詞"]
			while k <= partsLength - 1 and parts[k][0] != "、" :
				if (parts[k][1] in checkKei or parts[k][5] in checkKei) and "未然" not in parts[k][6] :
					outputText = parts[j][0]
					changeFlag = 0
				k += 1
				
			outputLines.append(outputText)

	return ''.join(outputLines).replace("!。！", '') + '\n'



# -*- coding: utf-8

import argparse
import os
import sys

from . import n2d
from . import d2n
from . import n2q
from . import q2n
from . import n2o
from . import o2n
from . import spj

def showVersion() :
	print(sys.version)
	sys.exit(0)

def cn2d(inputText) :
	return n2d.ND(inputText, args.detail)
def cn2q(inputText) :
	return n2q.NQ(inputText, args.detail)
def cn2o(inputText) :
	return n2o.NO(inputText, args.detail)

def cd2n(inputText) :
	return d2n.DN(inputText, args.detail)
def cd2q(inputText) :
	return n2q.NQ(d2n.DN(inputText, args.detail).strip(), args.detail)
def cd2o(inputText) :
	return n2o.NO(d2n.DN(inputText, args.detail).strip(), args.detail)

def cq2n(inputText) :
	return q2n.QN(inputText, args.detail)
def cq2d(inputText) :
	return n2d.ND(q2n.QN(inputText, args.detail).strip(), args.detail)
def cq2o(inputText) :
	return n2o.NO(q2n.QN(inputText, args.detail).strip(), args.detail)

def co2n(inputText) :
	return o2n.ON(inputText, args.detail)
def co2d(inputText) :
	return n2d.ND(o2n.ON(inputText, args.detail).strip(), args.detail)
def co2q(inputText) :
	return n2q.NQ(o2n.ON(inputText, args.detail).strip(), args.detail)

def convertSentences(inputText) :
	if args.n2d :
		return cn2d(inputText)
	elif args.n2q :
		return cn2q(inputText)
	elif args.n2o :
		return cn2o(inputText)

	elif args.d2n :
		return cd2n(inputText)
	elif args.d2q :
		return cd2q(inputText)
	elif args.d2o :
		return cd2o(inputText)

	elif args.q2n :
		return cq2n(inputText)
	elif args.q2d :
		return cq2d(inputText)
	elif args.q2o :
		return cq2o(inputText)

	elif args.o2n :
		return co2n(inputText)
	elif args.o2d :
		return co2d(inputText)
	elif args.o2q :
		return co2q(inputText)

	elif args.n :
		mode = spj.SPJ(inputText)
		if mode == "n" :
			return inputText.strip()
		elif mode == "d" :
			return cd2n(inputText)
		elif mode == "q" :
			return cq2n(inputText)
		elif mode == "o" :
			return co2n(inputText)
		else :
			sys.exit(0)

	elif args.d :
		mode = spj.SPJ(inputText)
		if mode == "n" :
			return cn2d(inputText)
		elif mode == "d" :
			return inputText.strip()
		elif mode == "q" :
			return cq2d(inputText)
		elif mode == "o" :
			return co2d(inputText)
		else :
			sys.exit(0)

	elif args.q :
		mode = spj.SPJ(inputText)
		if mode == "n" :
			return cn2q(inputText)
		elif mode == "d" :
			return cd2q(inputText)
		elif mode == "q" :
			return inputText.strip()
		elif mode == "o" :
			return co2q(inputText)
		else :
			sys.exit(0)

	elif args.o :
		mode = spj.SPJ(inputText)
		if mode == "n" :
			return cn2o(inputText)
		elif mode == "d" :
			return cd2o(inputText)
		elif mode == "q" :
			return cq2o(inputText)
		elif mode == "o" :
			return inputText.strip()
		else :
			sys.exit(0)

	else :
		sys.exit(0)

# コマンドライン引数の解析
parser = argparse.ArgumentParser(description = "詳しくはこちらをご覧下さい(https://pypi.org/project/csw/)。")

parser.add_argument("-v", "--version", action = "version", version = "%(prog)s 0.3.1")
parser.add_argument("--n2d", action = "store_true", help = "平叙文肯定から平叙文否定への変換")
parser.add_argument("--n2q", action = "store_true", help = "平叙文肯定から疑問文への変換")
parser.add_argument("--n2o", action = "store_true", help = "平叙文肯定か命令文への変換")

parser.add_argument("--d2n", action = "store_true", help = "平叙文否定から平叙文肯定への変換")
parser.add_argument("--d2q", action = "store_true", help = "平叙文否定から疑問文への変換")
parser.add_argument("--d2o", action = "store_true", help = "平叙文否定から命令文への変換")

parser.add_argument("--q2n", action = "store_true", help = "疑問文から平叙文肯定への変換")
parser.add_argument("--q2d", action = "store_true", help = "疑問文から平叙文否定への変換")
parser.add_argument("--q2o", action = "store_true", help = "疑問文から命令文への変換")

parser.add_argument("--o2n", action = "store_true", help = "命令文から平叙文肯定への変換")
parser.add_argument("--o2d", action = "store_true", help = "命令文から平叙文否定への変換")
parser.add_argument("--o2q", action = "store_true", help = "命令文から疑問文への変換")

parser.add_argument("--n", action = "store_true", help = "平叙文肯定への変換")
parser.add_argument("--d", action = "store_true", help = "平叙文否定への変換")
parser.add_argument("--q", action = "store_true", help = "疑問文への変換")
parser.add_argument("--o", action = "store_true", help = "命令文への変換")

parser.add_argument("-d", "--detail", action = "store_true", help = "形態素解析の結果を表示(fオプションとの併用不可)")
parser.add_argument("-c", "--current", action = "store_true", help = "一文ずつ入出力(fオプションとの併用不可)")
parser.add_argument("-f", "--file", nargs = 2, help = "ファイルでの入出力(その後ろに変換元ファイル名、変換先ファイル名を順に指定)")

args = parser.parse_args()

# 手動
if args.current :
	print("「e」か「え」を入力で終了")
	print("")
	while True :
		print("---------------------------------------------")

		print("input  : ", end = "")
		inputText = input()
		if inputText == 'e' or inputText == 'え' :
			break

		print("output : " + convertSentences(inputText).strip())

# ファイル入出力
elif args.file :
	iFile = args.file[0]
	oFile = args.file[1]

	with open(iFile, "r") as r :
		with open(oFile, "w") as w :
			for line in r :
				w.write(str(convertSentences(line.strip())))



import re
import MeCab
import os

def NQ(inputText, det) :
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")	
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger.parse('')

	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	if det :
		print(tagger.parse(inputText))

	# ！と。を前の文に含んで分割
	inputLines = []
	outputLines = []
	inputLines = re.split("(?<=！|。)", inputText)
	
	# 分割したときに出る空白文字列を除去 
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)

	for i in range(0, lineCount, 1) :
		parts = []
		meCount = 0
		changeFlag = 0
		impressFlag = 0

		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		while node :
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			if tmp1 == "感動詞" :
				impressFlag = 1
			elif impressFlag == 1 and "助" not in tmp1 :
				impressFlag = 0
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmp2 == "終助詞" :
				inputLines[i] = inputLines[i][::-1].replace(tmp2, '', 1)[::-1]
			
			elif tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			meCount += 1
			if meCount == length :
				break

			# ノードを進める
			node = node.next

		partsLength = len(parts)

		j1 = partsLength - 4
		j2 = partsLength - 3
		j3 = partsLength - 2

		if "？" in inputLines[i] :
			outputLines.append(inputLines[i])
			continue

		if parts[j2][0] == "ん" and parts[j2][1] == "名詞" :
			parts[j2][0] = "の"

		elif parts[j3][0] == "ん" and parts[j3][1] == "名詞" :
			parts[j3][0] = "の"

		if impressFlag == 1 :
			outputText = inputLines[i]

		elif parts[j2][1] == "動詞" and "命令" in parts[j2][6] :
			pass
		
		elif parts[j3][1] == "動詞" and ("命令" in parts[j3][6] or parts[j3][6] == "連用形") :
			pass

		elif parts[j3][0] == "だ" and ("ダ" in parts[j3][5] or "タ" in parts[j3][5]) and parts[j2][2] != "自立" and parts[j3][1] == "助動詞" and parts[j3][6] == "基本形" : 
			parts[j3][0] = "か？"
		
		elif parts[j2][1] == "動詞" and parts[j3][1] == "助動詞":
			parts[j3][0] += "か？"

		elif parts[j2][1] == "名詞" and parts[j3][1] == "助詞" and parts[j3][3] == "連語" :
			parts[j3][0] += "か？"

		elif parts[j2][1] == "名詞" and parts[j3][1] == "助動詞" :
			parts[j3][0] += "か？"

		elif parts[j2][1] == "助詞" and parts[j3][1] == "名詞" :
			parts[j3][0] += "か？"

		elif parts[j2][1] == "助詞" and parts[j3][1] == "連体詞" :
			parts[j3][0] += "か？"

		elif parts[j2][1] == "助詞" and parts[j3][1] == "動詞" :
			parts[j3][0] += "か？"

		elif parts[j3][1] == "助詞" and parts[j3][2] == "特殊" :
			parts[j3][0] = "か？"

		elif parts[j3][1] == "助詞" and "助詞" not in parts[j3][2] and parts[j3][3] != "連語" :
			parts[j3][0] += "か？"
	
		elif parts[j3][1] == "助動詞" and parts[j3][6] == "基本形" :
			parts[j3][0] += "か？"

		elif parts[j3][1] == "動詞" :
			parts[j3][0] += "か？"

		elif parts[j3][1] == "形容詞" :
			parts[j3][0] += "か？"

		elif parts[j3][1] == "副詞" :
			parts[j3][0] += "か？"
		
		elif parts[j3][1] == "名詞" :
			parts[j3][0] += "か？"

		elif parts[j3][2] == "副助詞" :
			parts[j3][0] += "か？"

		elif parts[j3][2] == "接続助詞" :
			parts[j3][0] = "か？"

		# 変換しないとき、そのままにする
		else :
			outputLines.append(inputLines[i])
			continue

		for p in range(0, partsLength, 1) :
			outputLines.append(parts[p][0])

	# ？の後ろの記号を消す
	retLines = ''.join(outputLines)
	retLines = re.sub("(?<=？)\W", "", retLines)
	
	return ''.join(retLines) + '\n'



# -*- coding: utf-8

import setuptools
import csw

with open('README.md', 'r') as fh:
	long_description = fh.read()

setuptools.setup(
	name = 'csw',
	version = csw.__version__,
	author = 'Sone-i',
	author_email = 'i18308@kagawa.kosen-ac.jp',
	description = "文自在変換ツール",
	long_description = long_description,
	long_description_content_type = 'text/markdown',
	url = 'https://github.com/Sone-i/csw',
	download_url = 'https://github.com/Sone-i/csw',
	packages = setuptools.find_packages(),
	classifiers = [
		'Programming Language :: Python :: 3',
		'License :: OSI Approved :: MIT License',
	],
	entry_points = {
		'console_scripts': ['csw = csw.csw:main']
	},
	python_requires = '>=3.7',
	install_requires = [
		'MeCab>=0.996'
	]
)



import re
import MeCab
import os

def godanHenkan(change) :
	if change == "い" :
		return change
	elif change in ["か", "き", "く", "こ"] :
		return "け"
	elif change in ["が", "ぎ", "ぐ", "ご"] :
		return "げ"
	elif change in ["さ", "し", "す", "そ"] :
		return "せ"
	elif change in ["た", "ち", "つ", "と"] :
		return "て"
	elif change in ["な", "に", "ぬ", "の"] :
		return "ね"
	elif change in ["ば", "び", "ぶ", "ぼ"] :
		return "べ"
	elif change in ["ま", "み", "む", "も"] :
		return "め"
	elif change in ["ら", "り", "る", "ろ"] :
		return "れ"
	elif change in ["わ", "い", "う", "お"] :
		return "え"
	else :
		return change

def NO(inputText, det) :
	tagger = MeCab.Tagger("-d /var/lib/mecab/dic/ipadic-utf8")	
	# 空文字列をparseすることでnode.surfaceのバグをケアする
	tagger.parse('')

	# 半角記号を全角にする
	inputText = inputText.replace("!", "！")
	inputText = inputText.replace(",", "、")
	inputText = inputText.replace(".", "。")
	inputText = inputText.replace("，", "、")
	inputText = inputText.replace("．", "。")

	if det :
		print(tagger.parse(inputText))

	# ！と。を前の文に含んで分割
	inputLines = []
	outputLines = []
	inputLines = re.split("(?<=。|！)", inputText)
	
	# 分割したときに出る空白文字列を除去 
	if '' in inputLines :
		inputLines.remove('')

	lineCount = len(inputLines)

	for i in range(0, lineCount, 1) :
		parts = []
		outputText = "tekitoudayo"
		meCount = 0
		changeFlag = 0
		impressFlag = 0
		hukusiFlag = 0
		changeHere = 0
		changeSur = "tekitoudayo"

		# inputLines[i]をノードとして扱う
		node = tagger.parseToNode(inputLines[i])

		# 形態素解析したときの行数(\nの数)を取得
		length = tagger.parse(inputLines[i]).count(os.linesep)

		while node:
			# 表層語を取ってくる
			tmpSurface = node.surface

			# 品詞を取ってくる
			tmp1 = node.feature.split(",")[0]
			if tmp1 == "動詞" :
				changeHere = meCount - 1
			
			tmp2 = node.feature.split(",")[1]
			tmp3 = node.feature.split(",")[2]
			tmp4 = node.feature.split(",")[3]
			tmp5 = node.feature.split(",")[4]
			tmp6 = node.feature.split(",")[5]
			tmp7 = node.feature.split(",")[6]

			if tmpSurface != "" :
				parts.append([tmpSurface, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7])

			meCount += 1
			if meCount == length:
				break

			# ノードを進める
			node = node.next

		# 文末に記号が無いとき、一時的につけて最後に除去する
		if tmp1 != "記号" :
			parts.append(["!。！", "記号", "**", "**", "**", "**", "**", "**"])

		partsLength = len(parts)

		k = changeHere + 1
		while parts[k][1] != "記号" :
			if parts[k][1] == "助動詞" and "タ" in parts[k][5] :
				changeHere = -1
			elif parts[k][1] != "助動詞" and (parts[k][1] != "助詞" or parts[k][2] != "終助詞") and (parts[k][1] != "名詞" or parts[k][2] != "非自立") :
				changeHere = -1
			k += 1

		for j in range(0, partsLength, 1) :
			if j == changeHere and (parts[j + 1][1] == "記号" or parts[j + 1][1] == "助動詞" or (parts[j + 1][1] == "助詞" and parts[j + 1][2] == "終助詞")) :
				if "五段" in parts[j][5] :
					changeSur = parts[j][0]
					change = godanHenkan(parts[j][0][-1:])
					parts[j][0] = parts[j][0][::-1].replace(parts[j][0][-1:], change, 1)[::-1]
					if changeSur != parts[j][0] :
						changeFlag = 1

				elif "一段" in parts[j][5] :
					parts[j][0] = parts[j][7][::-1].replace(parts[j][7][-1:], "ろ", 1)[::-1]
					changeFlag = 1

				elif "サ変" in parts[j][5] :
					parts[j][0] = "しろ"
					changeFlag = 1

				elif "カ変" in parts[j][5] :
					changeFlag = 1
					if parts[j][0] == "来る" :
						parts[j][0] = "来い"
					elif parts[j][0] == "くる" :
						parts[j][0] = "こい"
					else :
						changeFlag = 0

				k = j + 1
				while parts[k][1] != "記号" and changeFlag == 1 :
					if parts[k][1] == "助動詞" or (parts[k][1] == "助詞" and parts[k][2] == "終助詞") or (parts[k][1] == "名詞" and parts[k][2] == "非自立") :
						parts[k][0] = ''
					else :
						break
					k += 1

			outputLines.append(parts[j][0])

	return ''.join(outputLines).replace("!。！", '') + '\n'
